/*
Example for Fram_2 Click

    Date          : Jul 2017.
    Author        : Djordje Rosic

Test configuration STM32 :
    
    MCU             : STM32F107VCT6
    Dev. Board      : EasyMx PRO v7 for STM32 ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This example demonstrates the use of FRAM 2 click. It will first initialize
    peripherals and enable writing to FRAM. It will then write the value 42
    into register 0x10, and then read that value and output it via UART.

    Note: Turn on the UART switches on the board to enable uart output.

*/


#include <stdint.h>

sbit FRAM2_CS         at GPIOD_ODR.B13;


static void Fram_2_Write (uint8_t address1, uint8_t address2,
                          uint8_t address3, uint8_t writeData);
static uint8_t Fram_2_Read (uint8_t address1,
                            uint8_t address2, uint8_t address3);

void systemInit()
{
    GPIO_Digital_Output( &GPIOD_ODR, _GPIO_PINMASK_13 );
    SPI3_Init_Advanced( _SPI_FPCLK_DIV256, _SPI_MASTER | _SPI_8_BIT |
                        _SPI_CLK_IDLE_HIGH | _SPI_SECOND_CLK_EDGE_TRANSITION |
                        _SPI_MSB_FIRST | _SPI_SS_DISABLE | _SPI_SSM_ENABLE |
                        _SPI_SSI_1, &_GPIO_MODULE_SPI3_PC10_11_12 );

    UART1_Init_Advanced( 9600, _UART_8_BIT_DATA,
                                 _UART_NOPARITY,
                                 _UART_ONE_STOPBIT,
                                 &_GPIO_MODULE_USART1_PA9_10 );
    UART_Write_Text ("\r\nInitialized");
}

void Fram_2_Init()
{
    FRAM2_CS = 0;
    SPI_Write (0x06); //Write enable command is required prior to any write.
    FRAM2_CS = 1;
}

void Fram_2_Task()
{
    uint8_t readData;
    char outputText [5];
    memset ( outputText, 0, 5);
    UART_Write_Text ("\r\nWriting value 42 into register 0x10...");
    Fram_2_Write (0x00, 0x00, 0x10, 42 );

    UART_Write_Text ("\r\nReading from register 0x10...");
    readData = Fram_2_Read  (0x00, 0x00, 0x10);
    ShortToStr (readData, outputText);
    UART_Write_Text ("\r\nRead value: ");
    UART_Write_Text (outputText);
}

void main()
{
    systemInit();
    Fram_2_Init();

    Fram_2_Task();
}

static void Fram_2_Write (uint8_t address1, uint8_t address2,
                          uint8_t address3, uint8_t writeData)
{
    FRAM2_CS = 0;
    SPI_Write (0x02);             //Write OPcode
    SPI_Write (address1);
    SPI_Write (address2);
    SPI_Write (address3);
    SPI_Write (writeData);
    //More data can be written after this. Address pointer is auto-incremented.
    FRAM2_CS = 1;
}
static uint8_t Fram_2_Read (uint8_t address1,
                            uint8_t address2, uint8_t address3)
{
    FRAM2_CS = 0;
    SPI_Write (0x03);             //Read OPcode
    SPI_Write (address1);
    SPI_Write (address2);
    SPI_Write (address3);
    return SPI_Read (0x00);
    //More data can be read after this. Address pointer is auto-incremented.
    FRAM2_CS = 1;
}